=====
Croud
=====

.. image:: https://badge.fury.io/py/croud.svg
    :target: http://badge.fury.io/py/croud
    :alt: Version

.. image:: https://img.shields.io/badge/docs-latest-brightgreen.svg
    :target: https://crate.io/docs/cloud/en/latest/
    :alt: Documentation

|

*Croud* is a *command-line interface* (CLI) tool for CrateDB Cloud ☁.

Installation
============

Using pip
---------

``croud`` can be installed using pip_::

    $ python3 -m pip install --user -U croud


To update, run::

    $ pip install -U croud

Contributing
============

This project is primarily maintained by Crate.io_, but we welcome community
contributions!

See the `developer docs`_ and the `contribution docs`_ for more information.


Help
====

Looking for more help?

- Read the `project documentation`_
- Check `StackOverflow`_ for common problems
- Chat with us on `Slack`_
- Get `paid support`_

.. _pip: https://pip.pypa.io/en/stable/
.. _virtualenv: https://virtualenv.pypa.io/en/latest/
.. _contribution docs: https://github.com/crate/croud/blob/master/CONTRIBUTING.rst
.. _developer docs: https://github.com/crate/croud/blob/master/DEVELOP.rst
.. _Crate.io: http://crate.io/
.. _project documentation: https://crate.io/docs/cloud/en/latest/
.. _StackOverflow: https://stackoverflow.com/tags/crate
.. _Slack: https://crate.io/docs/support/slackin/
.. _paid support: https://crate.io/pricing/
